@@ -3,6 +3,6 @@ from .module_wrapper import *
 from .nce import *
 from .utils import *
 from .feature_extractor import *
-from .linear import *
+from .fully_connected import *
 from .pairwise_acc import *
 from .placeholder import *
